{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#germline_filter_vcf.cwl/annotated_vcf"
                },
                {
                    "type": "float",
                    "id": "#germline_filter_vcf.cwl/filter_gnomAD_maximum_population_allele_frequency"
                },
                {
                    "type": "string",
                    "id": "#germline_filter_vcf.cwl/gnomad_field_name"
                },
                {
                    "type": "File",
                    "id": "#germline_filter_vcf.cwl/limit_variant_intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#germline_filter_vcf.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputSource": "#germline_filter_vcf.cwl/index_filtered_vcf/indexed_vcf",
                    "id": "#germline_filter_vcf.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputSource": "#germline_filter_vcf.cwl/limit_variants/filtered_vcf",
                    "id": "#germline_filter_vcf.cwl/final_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#germline_filter_vcf.cwl/set_filtered_vcf_name/replacement",
                            "id": "#germline_filter_vcf.cwl/bgzip_filtered_vcf/file"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/bgzip_filtered_vcf/bgzipped_file"
                    ],
                    "id": "#germline_filter_vcf.cwl/bgzip_filtered_vcf"
                },
                {
                    "run": "#filter_vcf_coding_variant.cwl",
                    "in": [
                        {
                            "source": "#germline_filter_vcf.cwl/annotated_vcf",
                            "id": "#germline_filter_vcf.cwl/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#germline_filter_vcf.cwl/coding_variant_filter"
                },
                {
                    "run": "#filter_vcf_custom_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#germline_filter_vcf.cwl/gnomad_field_name",
                            "id": "#germline_filter_vcf.cwl/gnomad_frequency_filter/field_name"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/filter_gnomAD_maximum_population_allele_frequency",
                            "id": "#germline_filter_vcf.cwl/gnomad_frequency_filter/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/coding_variant_filter/filtered_vcf",
                            "id": "#germline_filter_vcf.cwl/gnomad_frequency_filter/vcf"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/gnomad_frequency_filter/filtered_vcf"
                    ],
                    "id": "#germline_filter_vcf.cwl/gnomad_frequency_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#germline_filter_vcf.cwl/bgzip_filtered_vcf/bgzipped_file",
                            "id": "#germline_filter_vcf.cwl/index_filtered_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/index_filtered_vcf/indexed_vcf"
                    ],
                    "id": "#germline_filter_vcf.cwl/index_filtered_vcf"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#germline_filter_vcf.cwl/limit_variants/exclude_filtered"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/limit_variant_intervals",
                            "id": "#germline_filter_vcf.cwl/limit_variants/interval_list"
                        },
                        {
                            "default": "annotated.filtered.final",
                            "id": "#germline_filter_vcf.cwl/limit_variants/output_vcf_basename"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/reference",
                            "id": "#germline_filter_vcf.cwl/limit_variants/reference"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/index_filtered_vcf/indexed_vcf",
                            "id": "#germline_filter_vcf.cwl/limit_variants/vcf"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/limit_variants/filtered_vcf"
                    ],
                    "id": "#germline_filter_vcf.cwl/limit_variants"
                },
                {
                    "run": "#staged_rename.cwl",
                    "in": [
                        {
                            "valueFrom": "annotated.filtered.vcf",
                            "id": "#germline_filter_vcf.cwl/set_filtered_vcf_name/name"
                        },
                        {
                            "source": "#germline_filter_vcf.cwl/gnomad_frequency_filter/filtered_vcf",
                            "id": "#germline_filter_vcf.cwl/set_filtered_vcf_name/original"
                        }
                    ],
                    "out": [
                        "#germline_filter_vcf.cwl/set_filtered_vcf_name/replacement"
                    ],
                    "id": "#germline_filter_vcf.cwl/set_filtered_vcf_name"
                }
            ],
            "id": "#germline_filter_vcf.cwl"
        },
        {
            "class": "Workflow",
            "label": "joint genotyping for trios or small cohorts",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom annotation file to be used by vep",
                            "fields": [
                                {
                                    "type": {
                                        "type": "record",
                                        "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info",
                                        "fields": [
                                            {
                                                "type": "boolean",
                                                "label": "Identify known variants colocated with input variant",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/check_existing"
                                            },
                                            {
                                                "type": {
                                                    "type": "enum",
                                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format",
                                                    "symbols": [
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bed",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gff",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gtf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/vcf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bigwig"
                                                    ],
                                                    "label": "Annotation file type"
                                                },
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format"
                                            },
                                            {
                                                "type": "File",
                                                "label": "File to be used for annotation, include index file",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/file"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    "boolean"
                                                ],
                                                "label": "Use this annotation for gnomad filtering?",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/gnomad_filter"
                                            },
                                            {
                                                "type": "string",
                                                "label": "Used as key for new VEP annotation",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/name"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    {
                                                        "type": "array",
                                                        "items": "string"
                                                    }
                                                ],
                                                "label": "List of VCF fields to annotate",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/vcf_fields"
                                            }
                                        ]
                                    },
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation"
                                },
                                {
                                    "type": "boolean",
                                    "label": "Force report the overlapping coordinates of custom feature instead of based on the exact coordinates",
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/force_report_coordinates"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "enum",
                                            "symbols": [
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/exact",
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/overlap"
                                            ],
                                            "label": "Require exact or overlap to annotate variants"
                                        }
                                    ],
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/method"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": "float",
                    "default": 0.05,
                    "id": "#main/filter_gnomAD_maximum_population_allele_frequency"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#main/final_tsv_prefix"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/gvcfs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "doc": "intervals used to parallelize genotyping. Example: [[chr1],[chr2],[chr3],[chr4,chr5]]",
                    "id": "#main/intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "doc": "region of interest interval list file, used to limit called variants in final filtered output files",
                    "id": "#main/roi_intervals"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#vep_custom_annotation.yml/vep_custom_annotation"
                    },
                    "doc": "custom type, check types directory for input format",
                    "id": "#main/vep_custom_annotations"
                },
                {
                    "type": "string",
                    "doc": "genome assembly to use in vep. Examples: GRCh38 or GRCm38",
                    "id": "#main/vep_ensembl_assembly"
                },
                {
                    "type": "string",
                    "doc": "ensembl species - Must be present in the cache directory. Examples: homo_sapiens or mus_musculus",
                    "id": "#main/vep_ensembl_species"
                },
                {
                    "type": "string",
                    "doc": "ensembl version - Must be present in the cache directory. Example: 95",
                    "id": "#main/vep_ensembl_version"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Frameshift",
                        "Wildtype"
                    ],
                    "id": "#main/vep_plugins"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/set_filtered_tsv_name/replacement",
                    "id": "#main/filtered_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_vcf/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/set_final_tsv_name/replacement",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_vcf/final_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/merge_vcfs/merged_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/raw_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/annotate_coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/vep_custom_annotations",
                            "id": "#main/annotate_variants/custom_annotations"
                        },
                        {
                            "source": "#main/vep_ensembl_assembly",
                            "id": "#main/annotate_variants/ensembl_assembly"
                        },
                        {
                            "source": "#main/vep_ensembl_species",
                            "id": "#main/annotate_variants/ensembl_species"
                        },
                        {
                            "source": "#main/vep_ensembl_version",
                            "id": "#main/annotate_variants/ensembl_version"
                        },
                        {
                            "source": "#main/vep_plugins",
                            "id": "#main/annotate_variants/plugins"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/merge_vcfs/merged_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/bgzip_index_annotated_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/bgzip_index_annotated_vcf/indexed_vcf"
                    ],
                    "id": "#main/bgzip_index_annotated_vcf"
                },
                {
                    "run": "#combine_gvcfs.cwl",
                    "in": [
                        {
                            "source": "#main/gvcfs",
                            "id": "#main/combine_gvcfs/gvcfs"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_gvcfs/reference"
                        }
                    ],
                    "out": [
                        "#main/combine_gvcfs/gvcf"
                    ],
                    "id": "#main/combine_gvcfs"
                },
                {
                    "run": "#germline_filter_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/filter_vcf/annotated_vcf"
                        },
                        {
                            "source": "#main/filter_gnomAD_maximum_population_allele_frequency",
                            "id": "#main/filter_vcf/filter_gnomAD_maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/vep_custom_annotations",
                            "valueFrom": "${\n   if(self){\n        for(var i=0; i<self.length; i++){\n            if(self[i].annotation.gnomad_filter){\n                return(self[i].annotation.name + '_AF');\n            }\n        }\n    }\n    return('gnomAD_AF');\n}\n",
                            "id": "#main/filter_vcf/gnomad_field_name"
                        },
                        {
                            "source": "#main/roi_intervals",
                            "id": "#main/filter_vcf/limit_variant_intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_vcf/reference"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf/filtered_vcf",
                        "#main/filter_vcf/final_vcf"
                    ],
                    "id": "#main/filter_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/final_tsv_prefix",
                            "id": "#main/filtered_add_vep_fields_to_table/prefix"
                        },
                        {
                            "source": "#main/filtered_variants_to_table/variants_tsv",
                            "id": "#main/filtered_add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/filter_vcf/filtered_vcf",
                            "id": "#main/filtered_add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/filtered_add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/filtered_add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/filtered_add_vep_fields_to_table"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/filtered_variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/filtered_variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/filtered_variants_to_table/reference"
                        },
                        {
                            "source": "#main/filter_vcf/filtered_vcf",
                            "id": "#main/filtered_variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/filtered_variants_to_table/variants_tsv"
                    ],
                    "id": "#main/filtered_variants_to_table"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/final_tsv_prefix",
                            "id": "#main/final_add_vep_fields_to_table/prefix"
                        },
                        {
                            "source": "#main/final_variants_to_table/variants_tsv",
                            "id": "#main/final_add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/filter_vcf/final_vcf",
                            "id": "#main/final_add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/final_add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/final_add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/final_add_vep_fields_to_table"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/final_variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/final_variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/final_variants_to_table/reference"
                        },
                        {
                            "source": "#main/filter_vcf/final_vcf",
                            "id": "#main/final_variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/final_variants_to_table/variants_tsv"
                    ],
                    "id": "#main/final_variants_to_table"
                },
                {
                    "scatter": [
                        "#main/genotype_gvcf/intervals"
                    ],
                    "run": "#gatk_genotypegvcfs.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/combine_gvcfs/gvcf"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/genotype_gvcf/gvcfs"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/genotype_gvcf/intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/genotype_gvcf/reference"
                        }
                    ],
                    "out": [
                        "#main/genotype_gvcf/genotype_vcf"
                    ],
                    "id": "#main/genotype_gvcf"
                },
                {
                    "run": "#picard_merge_vcfs.cwl",
                    "in": [
                        {
                            "source": "#main/genotype_gvcf/genotype_vcf",
                            "id": "#main/merge_vcfs/vcfs"
                        }
                    ],
                    "out": [
                        "#main/merge_vcfs/merged_vcf"
                    ],
                    "id": "#main/merge_vcfs"
                },
                {
                    "run": "#staged_rename.cwl",
                    "in": [
                        {
                            "valueFrom": "annotated.filtered.tsv",
                            "id": "#main/set_filtered_tsv_name/name"
                        },
                        {
                            "source": "#main/filtered_add_vep_fields_to_table/annotated_variants_tsv",
                            "id": "#main/set_filtered_tsv_name/original"
                        }
                    ],
                    "out": [
                        "#main/set_filtered_tsv_name/replacement"
                    ],
                    "id": "#main/set_filtered_tsv_name"
                },
                {
                    "run": "#staged_rename.cwl",
                    "in": [
                        {
                            "valueFrom": "annotated.filtered.final.tsv",
                            "id": "#main/set_final_tsv_name/name"
                        },
                        {
                            "source": "#main/final_add_vep_fields_to_table/annotated_variants_tsv",
                            "id": "#main/set_final_tsv_name/original"
                        }
                    ],
                    "out": [
                        "#main/set_final_tsv_name/replacement"
                    ],
                    "id": "#main/set_final_tsv_name"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "vep-annotation-reporter"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:4.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.prefix).annotated.tsv"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#add_vep_fields_to_table.cwl/prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature",
                        "HGVSc",
                        "HGVSp"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/usr/local/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK CombineGVCFs",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx8g",
                "CombineGVCFs"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--variant"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#combine_gvcfs.cwl/gvcfs"
                },
                {
                    "type": "string",
                    "default": "merged.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "--output",
                        "position": 3
                    },
                    "id": "#combine_gvcfs.cwl/output_file_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#combine_gvcfs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#combine_gvcfs.cwl/gvcf"
                }
            ],
            "id": "#combine_gvcfs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:vep_101.0_v1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_coding_variant.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#filter_vcf_coding_variant.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_coding_variant.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Custom allele frequency filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:vep_101.0_v1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_vcf_custom_allele_freq.cwl/field_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            inputs.field_name, \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", inputs.field_name\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_custom_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK GenotypeGVCFs",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx14g -Xms5g",
                "GenotypeGVCFs"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "arguments": [
                "-G",
                "StandardAnnotation",
                "-O",
                "genotype.vcf.gz"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_genotypegvcfs.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--variant"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gatk_genotypegvcfs.cwl/gvcfs"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-L"
                            }
                        }
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_genotypegvcfs.cwl/intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_genotypegvcfs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "genotype.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_genotypegvcfs.cwl/genotype_vcf"
                }
            ],
            "id": "#gatk_genotypegvcfs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/local/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.11--h6270b1f_0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Picard MergeVcfs",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx38g",
                "-jar",
                "/gatk/gatk.jar",
                "MergeVcfs"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 40000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "arguments": [
                "-O",
                "$(inputs.merged_vcf_basename).vcf.gz"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "merged",
                    "id": "#picard_merge_vcfs.cwl/merged_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-D"
                    },
                    "id": "#picard_merge_vcfs.cwl/sequence_dictionary"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-I"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#picard_merge_vcfs.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.merged_vcf_basename).vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_merge_vcfs.cwl/merged_vcf"
                }
            ],
            "id": "#picard_merge_vcfs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 4.1.8.1)",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx4g",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--exclude-filtered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample-name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-select-type",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Staged Renamer",
            "doc": "Renames a file by staging and then `mv`ing it.  A workaround for workflow engines that don't support rename.cwl.  If running in cwltool, use the other one instead.",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.original)"
                    ]
                }
            ],
            "baseCommand": [
                "/bin/mv"
            ],
            "arguments": [
                "$(inputs.original.basename)",
                "$(inputs.name)"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#staged_rename.cwl/name"
                },
                {
                    "type": "File",
                    "id": "#staged_rename.cwl/original"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    },
                    "id": "#staged_rename.cwl/replacement"
                }
            ],
            "id": "#staged_rename.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 4.1.8.1)",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx4g",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "default": [
                        "GT",
                        "AD",
                        "DP",
                        "AF"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#vep_custom_annotation.yml/vep_custom_annotation"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:vep_101.0_v2"
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--fork",
                "4",
                "--term",
                "SO",
                "--transcript_version",
                "--offline",
                "--cache",
                "--symbol",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.vcf.nameroot)_annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--dir",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom type, check types directory for input format",
                            "inputBinding": {
                                "valueFrom": "${\n    return [self.annotation.check_existing ? '--check_existing' : '',\n      '--custom',\n      [self.annotation.file.path,\n      self.annotation.name,\n      self.annotation.data_format,\n      self.method,\n      self.force_report_coordinates ? 1 : 0,\n      self.annotation.vcf_fields ? self.annotation.vcf_fields : ''\n      ].filter(String).join(',')\n    ].filter(String)\n}\n",
                                "position": 6
                            }
                        }
                    ],
                    "id": "#vep.cwl/custom_annotations"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--assembly",
                        "position": 10
                    },
                    "doc": "genome assembly to use in vep. Examples: 'GRCh38' or 'GRCm38'",
                    "id": "#vep.cwl/ensembl_assembly"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--species",
                        "position": 12
                    },
                    "doc": "ensembl species - Must be present in the cache directory. Examples: 'homo_sapiens' or 'mus_musculus'",
                    "id": "#vep.cwl/ensembl_species"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--cache_version",
                        "position": 11
                    },
                    "doc": "ensembl version - Must be present in the cache directory. Example: '95'",
                    "id": "#vep.cwl/ensembl_version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--everything",
                        "position": 9
                    },
                    "id": "#vep.cwl/everything"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vep.cwl/pick/pick",
                                "#vep.cwl/pick/flag_pick",
                                "#vep.cwl/pick/pick_allele",
                                "#vep.cwl/pick/per_gene",
                                "#vep.cwl/pick/pick_allele_gene",
                                "#vep.cwl/pick/flag_pick_allele",
                                "#vep.cwl/pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "default": "flag_pick",
                    "inputBinding": {
                        "prefix": "--",
                        "separate": false,
                        "position": 7
                    },
                    "id": "#vep.cwl/pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--plugin"
                        }
                    },
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#vep.cwl/plugins"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta",
                        "position": 7
                    },
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
